@@ -3,10 +3,11 @@ package YAML::Node;
 use strict;
 use warnings;
 
-use YAML::Base;
 use YAML::Tag;
+require YAML::Mo;
 
-our @ISA     = 'YAML::Base';
+use Exporter;
+our @ISA     = 'Exporter';
 our @EXPORT  = qw(ynode);
 
 sub ynode {
@@ -27,7 +28,7 @@ sub new {
     my ($class, $node, $tag) = @_;
     my $self;
     $self->{NODE} = $node;
-    my (undef, $type) = $class->node_info($node);
+    my (undef, $type) = YAML::Mo::Object->node_info($node);
     $self->{KIND} = (not defined $type) ? 'scalar' :
                     ($type eq 'ARRAY') ? 'sequence' :
 		    ($type eq 'HASH') ? 'mapping' :
